@@ -2,9 +2,9 @@ TEMPLATE_REPO_URLS = [
     "git@github.com:luke-lombardi/slai_template.git",
     "https://github.com/luke-lombardi/slai_template.git",
 ]  # TODO: move to slai github
-NOTEBOOK_TRAINER_PREFIX = "keep"  # maybe rename to #export?
-DEFAULT_TRAINER_TIMEOUT_S = 60 * 5  # 5 minutes
 MODEL_WATCH_INTERVAL_S = 1
+LOCAL_CONFIG_PATH = ".slai/local_config.yml"
+GOOGLE_DRIVE_CONFIG_PATH = ".slai/google_drive_config.yml"
 REQUIREMENTS_RETURN_CODE_SUCCESS = 0
 REQUIREMENTS_RETURN_CODE_MISSING_DEP = 1
 REQUIREMENTS_RETURN_CODE_IMPORT_ERROR = 2
