@@ -1,16 +1,15 @@
 from slai.clients.model import get_model_client
 from slai.clients.project import get_project_client
 from slai_cli.create.local_config_helper import LocalConfigHelper
-from slai_cli import log
 from slai_cli.modules.docker_client import DockerClient
-from slai_cli import constants
+from slai_cli import log, constants
 
 
 def _install_requirement_interactively(*, model_name, docker_client, requirement):
     exit_code = docker_client.install_requirement(
         model_name=model_name, requirement=requirement
     )
-    if exit_code != 0:
+    if exit_code != constants.REQUIREMENTS_RETURN_CODE_SUCCESS:
         log.warn(f"Failed to install: {requirement}")
 
 
@@ -18,9 +17,6 @@ def _check_imports(*, model_name, model_version_id, docker_client):
     exit_code = docker_client.check_trainer_imports(
         model_name=model_name, model_version_id=model_version_id
     )
-    import pdb
-
-    pdb.set_trace()
 
     if exit_code == constants.REQUIREMENTS_RETURN_CODE_MISSING_DEP:
         if log.action_confirm(
@@ -39,14 +35,14 @@ def _check_imports(*, model_name, model_version_id, docker_client):
             return constants.REQUIREMENTS_RETURN_CODE_EXIT
     elif exit_code == constants.REQUIREMENTS_RETURN_CODE_FILE_NOT_FOUND_ERROR:
         log.warn(
-            "Trainer script not found, run `slai model save <model_name>` to generate a training script."  # noqa
+            "Trainer script not found, run `slai model save <model_name>` to generate a training script from your notebook."  # noqa
         )
         return constants.REQUIREMENTS_RETURN_CODE_EXIT
     elif exit_code == constants.REQUIREMENTS_RETURN_CODE_IMPORT_ERROR:
         log.warn("Trainer script failed due to import error.")
         return constants.REQUIREMENTS_RETURN_CODE_EXIT
 
-    return 0
+    return constants.REQUIREMENTS_RETURN_CODE_SUCCESS
 
 
 def _run_trainer(*, model_name, model_version_id, docker_client):
@@ -78,7 +74,7 @@ def _run_trainer(*, model_name, model_version_id, docker_client):
     else:
         exit_code = import_return_code
 
-    if exit_code != 0:
+    if exit_code != constants.REQUIREMENTS_RETURN_CODE_SUCCESS:
         log.warn(f"Trainer script failed with return code: {exit_code}")
         log.warn("Training failed.")
         return False
