@@ -4,11 +4,11 @@ import threading
 import time
 import queue
 import socket
-import json
 import ast
 
-from slai_cli import log
 from select import select
+from slai_cli import log
+from slai_cli.exceptions import RetryException
 
 DOCKER_SOCKET_READ_SIZE = 1024
 DOCKER_INPUT_UPDATE_RATE = 0.2
@@ -133,13 +133,13 @@ class DockerClient:
         trainer_path = f"/workspace/models/{model_name}/{model_version_id}/trainer.py"
 
         exit_code = self._run_interactive_command(
-            cmd=f"/workspace/env/{model_name}/bin/python /workspace/bin/check_imports.py {trainer_path}"
+            cmd=f"/workspace/env/{model_name}/bin/python /workspace/bin/check_imports.py {trainer_path}"  # noqa
         )
         return exit_code
 
     def generate_model_handler_requirements(self, *, model_name):
         _, output = self.project_container.exec_run(
-            f"/workspace/env/{model_name}/bin/python /workspace/bin/generate_handler_requirements.py {model_name}",
+            f"/workspace/env/{model_name}/bin/python /workspace/bin/generate_handler_requirements.py {model_name}",  # noqa
         )
         model_handler_requirements = ast.literal_eval(output.decode("utf-8"))
         return model_handler_requirements
@@ -147,11 +147,37 @@ class DockerClient:
     def check_handler_imports(self, *, model_name):
         handler_path = f"/workspace/handlers/{model_name}/handler.py"
         exit_code = self._run_interactive_command(
-            cmd=f"/workspace/env/{model_name}/bin/python /workspace/bin/check_imports.py {handler_path}"
+            cmd=f"/workspace/env/{model_name}/bin/python /workspace/bin/check_imports.py {handler_path}"  # noqa
         )
         return exit_code
 
-    def _run_interactive_command(self, *, cmd):
+    def launch_local_notebook_server(self, *, model_name):
+        _, output = self.project_container.exec_run(
+            "fuser -k 8888/tcp"
+        )  # kill any running notebook servers
+
+        killed_process = output.decode("utf-8").strip()
+        if killed_process:
+            log.action(f"Stopped existing notebook server: {killed_process}")
+
+        try:
+            _, output = self.project_container.exec_run(
+                f"/workspace/env/{model_name}/bin/python -m jupyter notebook --allow-root --ip='0.0.0.0' --NotebookApp.token='' --NotebookApp.password='' --no-browser",  # noqa
+                detach=True,
+            )
+        except docker.errors.APIError as e:
+            if "python: no such file" in e.response.json()["message"]:
+                log.warn(
+                    "No virtual environment found for this model, checking environment..."
+                )
+                self.create_model_environment(model_name=model_name)
+                raise RetryException
+            else:
+                return False
+
+        return True
+
+    def _run_interactive_command(self, *, cmd, silent=False):
         input_queue = queue.Queue()
         output_queue = queue.Queue()
         stop_event = threading.Event()
@@ -189,8 +215,9 @@ class DockerClient:
 
             if not output_queue.empty():
                 resp = output_queue.get()
-                sys.stdout.write(resp)
-                sys.stdout.flush()
+                if not silent:
+                    sys.stdout.write(resp)
+                    sys.stdout.flush()
 
             process_info = self.docker_api_client.exec_inspect(exec_id)
             process_running = process_info["Running"]
@@ -198,7 +225,8 @@ class DockerClient:
         stop_event.set()
         s.close()
 
-        sys.stdout.write("\n")
-        sys.stdout.flush()
+        if not silent:
+            sys.stdout.write("\n")
+            sys.stdout.flush()
 
         return process_info["ExitCode"]
